starcluster.progressbar.Bar

Package starcluster :: Module progressbar :: Class Bar |
[hide private]
[frames] | no frames]

# Class Bar

source code

The bar of progress. It will strech to fill the line.

Instance Methods | [hide private]
__init__(self, marker=`'``#``'`, left=`'``|``'`, right=`'``|``'`) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
_format_marker(self, pbar) | source code
update(self, pbar, width) Returns the string representing the widget. | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, marker=`'``#``'`, left=`'``|``'`, right=`'``|``'`) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### update(self, pbar, width) | source code
Returns the string representing the widget. The parameter pbar is a reference to the calling ProgressBar, where one can access attributes of the class for knowing how the update must be made. The parameter width is the total horizontal width the widget must have. At least this function must be overriden. Overrides: ProgressBarWidgetHFill.update (inherited documentation)